# Galo-MethodDecorators

![Test workflow](https://github.com/maximsakhno/galo-method-decorators/actions/workflows/test.yml/badge.svg)
[![codecov](https://codecov.io/gh/maximsakhno/galo-method-decorators/branch/master/graph/badge.svg?token=Z5ZDJ3N02S)](https://codecov.io/gh/maximsakhno/galo-method-decorators)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/galo_mehtod_decorators)](https://pypi.org/project/galo_method_decorators/)
[![PyPI](https://img.shields.io/pypi/v/galo_method_decorators)](https://pypi.org/project/galo_method_decorators/)
![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)

A Python library that allows you to use decorators for instance methods without affecting the methods in the class.

## Installation

The package is available on the [PyPi](https://pypi.org/project/galo_method_decorators/):

```commandline
pip install galo_method_decorators
```
